#ifndef _LC_CMD
#define _LC_CMD

#include <arpa/inet.h>
#include "global_vars.h"

int cmd_q(struct client_t *who, int cmd, char *msg, int msglen);
int cmd_direct(int cmd, int sock, struct sockaddr_in *who, char *msg, int mlen, char type);
int cmd_direct_udp(int cmd, struct sockaddr_in *who, char *msg, int mlen);
int cmd_direct_tcp(int cmd, int sock, struct sockaddr_in *, char *, int);
int cmd_broadcast(int cbr, char *msg, int mlen);
int ack_remove(struct p_order_t *pack, struct sockaddr_in *from);
int ack_send(struct sockaddr_in *trg, struct p_order_t *cmdpack);
int ack_proc(int ip, short port); // handles a received ack:
 // remove ackq entry
 // look for commands to send
int ackq_check(); // looks for timed out acks
int secure_write(int sock, void *buf, int len);
//int secure_write(int sock, int ip, unsigned short port, void *buf, int len);

#endif /* _LC_CMD */
